@@ -162,7 +162,7 @@ def run_simulation(n_of_families = 250,
     if n_test < 0:
         print("Invalid number of test per day")
         sys.exit()
-    if policy_test not in ["Random", "Degree Centrality", "Betweenness Centrality", "PBI"]:
+    if policy_test not in ["", "Random", "Degree Centrality", "Betweenness Centrality", "PBI"]:
         print("Invalid test strategy")
         sys.exit()
     if contact_tracing_efficiency < 0 or contact_tracing_efficiency > 1:
@@ -177,6 +177,8 @@ def run_simulation(n_of_families = 250,
     if restriction_duration < 0:
         print("Invalid restriction restriction_duration")
         sys.exit()
+    if policy_test == "":
+        n_test = 0
     if restriction_duration == 0:
         restriction_decreasing = False
         social_distance_strictness = 0
